# Copyright © 2025, Alexander Suvorov


class Config:
    name = 'Smart Password Manager CLI v2.1.1'
    url = 'https://github.com/smartlegionlab/clipassman'
    help_url = 'https://github.com/smartlegionlab/smartpasslib'
    info = 'Copyright © 2025, Alexander Suvorov'
    version = "v2.1.1"
